.. _api:

===
API
===

.. autofunction:: admin_extra_urls.api.button


.. autofunction:: admin_extra_urls.api.href


=========
Utilities
=========

.. autofunction:: admin_extra_urls.mixins.ExtraUrlMixin.get_common_context

